/**
 * JASMINe
 * Copyright (C) 2007-2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JasmineEventEJB3Wrapper.java 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.endpoints;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.naming.NamingException;

import org.ow2.jasmine.event.messages.JasmineEventTimer;
import org.ow2.jasmine.monitoring.eventswitch.beans.JasmineEventTimerSLBRemote;

/**
 * A wrapper class that accesses JasmineEvent objects via EJB3.
 */
public class JasmineEventEJB3TimerWrapper extends MuleEJB3Wrapper<JasmineEventTimerSLBRemote> {

    /**
     * Starts the {@link MuleEJB3Wrapper} in deferred mode.
     */
    public JasmineEventEJB3TimerWrapper() {
        super(true);
    }


    public void configureJasmineEventTimer(final JasmineEventTimer event) {
        ClassLoader currentClassLoader = Thread.currentThread().getContextClassLoader();
        Thread.currentThread().setContextClassLoader(JasmineEventEJB3TimerWrapper.class.getClassLoader());
        try {
            getBean().configureTimer(event);
        } catch (NamingException e) {
            Logger.getLogger(JasmineEventEJB3TimerWrapper.class.getName()).log(Level.WARNING,"EJBs are not ready ... the message is not persisted");
        } catch (IOException e) {
            Logger.getLogger(JasmineEventEJB3TimerWrapper.class.getName()).log(Level.WARNING,"EJBs are not ready ... the message is not persisted");
        } finally {
            Thread.currentThread().setContextClassLoader(currentClassLoader);
        }
    }

}
