/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * $Id: JasmineEventNotificationToCSV.java 4798 2009-08-07 12:30:47Z alitokmen $
 */
package org.ow2.jasmine.monitoring.eventswitch.transformers;

import java.text.SimpleDateFormat;
import java.util.Map;

import org.mule.transformers.AbstractTransformer;
import org.mule.umo.transformer.TransformerException;

import org.ow2.jasmine.event.beans.JasmineEventNotification;
import org.ow2.jasmine.event.beans.JasmineEventNotificationDetail;



/**
 * @author poutchjp
 */
public class JasmineEventNotificationToCSV extends AbstractTransformer {

    /**
     * Registers the transformer on Mule.
     *
     * @see org.mule.transformers.AbstractTransformer
     */
    public JasmineEventNotificationToCSV() {
        super();
        this.registerSourceType(JasmineEventNotification.class);
        this.setReturnClass(String.class);
    }

    /**
     * Transforms a JASMINe event notification into CVS string.
     *
     * @param src      @see org.mule.transformers.AbstractTransformer.doTransform
     * @param encoding @see org.mule.transformers.AbstractTransformer.doTransform
     *
     * @return src transformed into a CSV string.
     */
    @Override
    protected Object doTransform(Object src, String encoding) throws TransformerException {

        String result = "";

        final String split = ";";

        if (src instanceof JasmineEventNotification) {
            JasmineEventNotification event = (JasmineEventNotification) src;

            result += event.getId() + split
                    + event.getLevel() + split
                    + event.getMessage() + split
                    + (new SimpleDateFormat("MM/dd/yyyy, HH:mm:ss z").format(event.getDate())) + split
                    + event.getMessage() + split
                    + event.getStatus() + split;

            if (!event.getDetails().isEmpty()) {
                for (JasmineEventNotificationDetail entry : event.getDetails()) {
                    result += entry.getLabel() + ":" +entry.getMessage();
                }
            }
        } else {
            throw new IllegalArgumentException("Unable to transform this source type: " + src.getClass().getName());
        }

        result += "\n";
        return result;
    }
}
